summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/mymoneyobject.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/mymoneyobject.h')
-rw-r--r--kmymoney2/mymoney/mymoneyobject.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/mymoney/mymoneyobject.h b/kmymoney2/mymoney/mymoneyobject.h
index 854bf4d..cd8d43d 100644
--- a/kmymoney2/mymoney/mymoneyobject.h
+++ b/kmymoney2/mymoney/mymoneyobject.h
@@ -78,12 +78,12 @@ public:
/**
* This method creates a TQDomElement for the @p document
* under the tqparent node @p tqparent.
*
* @param document reference to TQDomDocument
* @param tqparent reference to TQDomElement tqparent node
*/
- virtual void writeXML(TQDomDocument& document, TQDomElement& tqparent) const = 0;
+ virtual void writeXML(TQDomDocument& document, TQDomElement& parent) const = 0;
bool operator == (const MyMoneyObject& right) const;
@@ -78,12 +78,12 @@ public:
/**
* This method creates a TQDomElement for the @p document
- * under the tqparent node @p tqparent.
+ * under the parent node @p parent.
*
* @param document reference to TQDomDocument
@@ -78,12 +78,12 @@ public:
*
* @param document reference to TQDomDocument
- * @param tqparent reference to TQDomElement tqparent node
+ * @param parent reference to TQDomElement parent node
*/